@@ -429,7 +429,7 @@ int main(int argc, char **argv) {
 	    int i, n, r;
 
 	    r = poll(ufds, nfds, -1);
-	    if (r < 0) die("poll failed unexpectedly\n");
+	    if ((r < 0) && (errno != EINTR)) die("poll failed unexpectedly\n");
 	    for (n = 0; n < nfds; n++) {
 #		define TTYWATCH_BUFSIZE 1024
 		char buf[TTYWATCH_BUFSIZE];
